pub struct Stylesheet {
pub paragraph: Vec<ParagraphStyle>,
pub run: Vec<RunStyle>,
pub table: Vec<TableStyle>,
}Expand description
A collection of reusable paragraph, run, and table styles.
Fields
paragraph: Vec<ParagraphStyle>Ordered paragraph.
run: Vec<RunStyle>Ordered run.
table: Vec<TableStyle>Ordered table.
Implementations
Sourceimpl Stylesheet
impl Stylesheet
Sourcepub fn paragraph_styles(&self) -> Iter<'_, ParagraphStyle> ⓘ
pub fn paragraph_styles(&self) -> Iter<'_, ParagraphStyle> ⓘ
Returns paragraph styles in document order.
Sourcepub fn run_styles(&self) -> Iter<'_, RunStyle> ⓘ
pub fn run_styles(&self) -> Iter<'_, RunStyle> ⓘ
Returns run styles in document order.
Sourcepub fn table_styles(&self) -> Iter<'_, TableStyle> ⓘ
pub fn table_styles(&self) -> Iter<'_, TableStyle> ⓘ
Returns table styles in document order.
Sourcepub fn define_paragraph_style(&mut self, style: ParagraphStyle) -> &mut Self
pub fn define_paragraph_style(&mut self, style: ParagraphStyle) -> &mut Self
Inserts or replaces a paragraph style by id.
Sourcepub fn add_paragraph_style(self, style: ParagraphStyle) -> Self
pub fn add_paragraph_style(self, style: ParagraphStyle) -> Self
Inserts or replaces a paragraph style by id in builder style.
Sourcepub fn define_run_style(&mut self, style: RunStyle) -> &mut Self
pub fn define_run_style(&mut self, style: RunStyle) -> &mut Self
Inserts or replaces a run style by id.
Sourcepub fn add_run_style(self, style: RunStyle) -> Self
pub fn add_run_style(self, style: RunStyle) -> Self
Inserts or replaces a run style by id in builder style.
Sourcepub fn define_table_style(&mut self, style: TableStyle) -> &mut Self
pub fn define_table_style(&mut self, style: TableStyle) -> &mut Self
Inserts or replaces a table style by id.
Sourcepub fn add_table_style(self, style: TableStyle) -> Self
pub fn add_table_style(self, style: TableStyle) -> Self
Inserts or replaces a table style by id in builder style.
Sourcepub fn paragraph_style(&self, style_id: &str) -> Option<&ParagraphStyle>
pub fn paragraph_style(&self, style_id: &str) -> Option<&ParagraphStyle>
Returns a paragraph style by id.
Sourcepub fn table_style(&self, style_id: &str) -> Option<&TableStyle>
pub fn table_style(&self, style_id: &str) -> Option<&TableStyle>
Returns a table style by id.